
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#define TAM_BUFFER 100
#define TAM_TABULEIRO 10

#define NMAX_PALAVRAS 10

typedef struct{

    int li;     // linha inicial
    int ci;     // coluna inicial
    int t;      // tamanho
    int s;      // sentido

} Resposta;


typedef struct{

    char tabuleiro[TAM_TABULEIRO][TAM_TABULEIRO];
    Resposta resposta[NMAX_PALAVRAS];
    int nPalavras;  // número de palavras escondidas

} Jogo;


// Protótipos
void leituraDosArquivosComPreenchimentoEstruturas (Jogo *jogo, Resposta *resposta, char palavra[]);
void atualizaJogo (Jogo *jogo, Resposta *umaResposta);

void escritaEmArquivo (Jogo *jogo);



int main (void)
{
    Jogo jogo;
    Resposta umaResposta;
    char umaPalavra[TAM_BUFFER];

    leituraDosArquivosComPreenchimentoEstruturas(&jogo, &umaResposta, umaPalavra);
    escritaEmArquivo(&jogo);

    return 0;
}


void leituraDosArquivosComPreenchimentoEstruturas (Jogo *jogo, Resposta *umaResposta, char umaPalavra[])
{

    int i = 0;

    jogo->nPalavras = 0; // o número de palavras será descoberto a partir de respostas.txt


    FILE *fi1 = fopen("caçaPalavras.txt", "r");
    FILE *fi2 = fopen("respostas.txt", "r");

    if(!fi1){
        printf("O arquivo caçaPalavras.txt não pode ser aberto para leitura.");
        exit(1);
    }

    if(!fi2){
        printf("O arquivo respostas.txt não pode ser aberto para leitura.");
        exit(1);
    }

    while(!feof(fi1)){
        fgets(umaPalavra, TAM_BUFFER, fi1);
        strncpy(jogo->tabuleiro[i], umaPalavra, TAM_TABULEIRO);

        i++;
    }


    while(!feof(fi2)){

        fscanf(fi2, "%d,%d,%d,%d\n",    &umaResposta->li, &umaResposta->ci,
                                        &umaResposta->t,  &umaResposta->s);


        jogo->resposta[jogo->nPalavras] = *umaResposta;
        jogo->nPalavras++;


        if(jogo->nPalavras>NMAX_PALAVRAS){
            printf("Erro. Foi excedido o número máximo de palavras.\n");
            exit(1);
        }

    }

    fclose(fi1);
    fclose(fi2);

}


void escritaEmArquivo (Jogo *jogo)
{
    FILE *fo  = fopen("gabarito.txt", "w");

    if(!fo){
        printf("O arquivo gabarito.txt não pode ser aberto para escrita.");
        exit(1);
    }


    int i = 0;

    // extrai as palavras respostas do caça-palavras
    for(i=0; i<jogo->nPalavras; i++){
        int li = jogo->resposta[i].li;
        int ci = jogo->resposta[i].ci;
        int t = jogo->resposta[i].t;
        int s = jogo->resposta[i].s;

        int l = li-1;
        int c = ci-1;

        if(s==0){   // horizontal
            for(c=ci-1; c<ci-1+t; c++){
                fputc(jogo->tabuleiro[l][c], fo);
            }
        }
        else{   // vertical
            for(l=li-1; l<li-1+t; l++){
                fputc(jogo->tabuleiro[l][c], fo);
            }
        }
        fputc('\n', fo);
    }


    fclose(fo);
}



